@@ -45,6 +45,8 @@ class Overclock:
     def _setup_overclock(self, builder):
         self.cputemp_label = builder.get_object("cpuTempLabel")
         self.overclockbutton = builder.get_object("OverclockButton")
+        self.model_label = builder.get_object("ModelLabel")
+        self.memory_label = builder.get_object("MemoryLabel")
         self.speedlabel = builder.get_object("SpeedLabel")
         self.speed_radiobuttons = [
                 builder.get_object("Default_Speed_radiobutton"),
@@ -58,6 +60,10 @@ class Overclock:
         if self.pi_model in self.PI_1800_MODELS:
             # if Pi is Model 400, disable 1.5GHz, since its default is 1.8GHz
             self.speed_radiobuttons[0].set_sensitive(False)
+        model = self.get_pimodel_line().split(':')
+        if len(model) > 1:
+            self.model_label.set_text(model[1])
+        self.memory_label.set_text(self.get_model_memory())
 
         app_statuslabel = builder.get_object("AppStatusLabel")
         tab = builder.get_object("OverclockTab")
@@ -78,15 +84,18 @@ class Overclock:
     def start_tempmonitor(self):
         GLib.timeout_add_seconds(1, self._temp_monitor)
 
-    def get_pimodel(self):
+    def get_pimodel_line(self):
         model_line = ''
         with open('/proc/cpuinfo', 'r') as cpufile:
             lines = cpufile.readlines()
             for line in lines:
                 if line.split(':')[0].rstrip(' \t\n') in ["Model", "model name"]:
-                    model_line = line
+                    model_line = line.strip()
                     break
-        # Scan through model/cpu arguments
+        return model_line
+
+    def get_pimodel(self):
+        model_line = self.get_pimodel_line()
         for i in range(len(self.model_list)):
             if self.model_list[i][1] in model_line:
                 return self.model_list[i][0]
@@ -101,6 +110,21 @@ class Overclock:
             return 'Pi'
         return None
 
+    def get_model_memory(self):
+        with open('/proc/meminfo', 'r') as memfile:
+            lines = memfile.readlines()
+            for line in lines:
+                if line.split(':')[0].rstrip(' \t\n') == "MemTotal":
+                    mem_line = line.split()
+                    break
+        if len(mem_line) > 1:
+            try:
+               memory = int(round(float(mem_line[1]) / 976600))
+               return str(memory) + "GB"
+            except:
+               pass
+        return "unknown"
+
     def _set_currentspeed(self):
         if self.currentspeed == 'error' or self.currentspeed == '1500':
             self.currentspeed = '1800' if self.pi_model == '400' else '1500'
